{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Matplotlib - 2D and 3D plotting in Python"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This entire tutorial is taken from J.R. Johansson's page ([http://jrjohansson.github.io](http://jrjohansson.github.io)). Brilliant Job!!!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "# This line configures matplotlib to show figures embedded in the notebook, \n",
    "# instead of opening a new window for each figure, similar to Exercise-0-Jupyter \n",
    "%matplotlib inline"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Introduction"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Matplotlib is an excellent 2D and 3D graphics library for generating scientific figures. Some of the many advantages of this library include:\n",
    "\n",
    "* Easy to get started\n",
    "* Great control of every element in a figure, including figure size and DPI. \n",
    "* High-quality output in many formats, including PNG, PDF, SVG, EPS, and PGF.\n",
    "* GUI for interactively exploring figures *and* support for headless generation of figure files (useful for batch jobs).\n",
    "\n",
    "One of the key features of matplotlib that I would like to emphasize, and that I think makes matplotlib highly suitable for generating figures for scientific publications is that all aspects of the figure can be controlled *programmatically*. This is important for reproducibility and convenient when one needs to regenerate the figure with updated data or change its appearance. \n",
    "\n",
    "More information at the Matplotlib web page: http://matplotlib.org/"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "To get started using Matplotlib in a Python program, either include the symbols from the `pylab` module (the easy way):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "from pylab import *"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "or import the `matplotlib.pyplot` module under the name `plt` (the tidy way):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "import matplotlib\n",
    "import matplotlib.pyplot as plt"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "import numpy as np"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## MATLAB-like API"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The easiest way to get started with plotting using matplotlib is often to use the MATLAB-like API provided by matplotlib. \n",
    "\n",
    "It is designed to be compatible with MATLAB's plotting functions, so it is easy to get started with if you are familiar with MATLAB.\n",
    "\n",
    "To use this API from matplotlib, we need to include the symbols in the `pylab` module: "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "from pylab import *"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Example"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "A simple figure with MATLAB-like plotting API:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "x = np.linspace(0, 5, 10)\n",
    "y = x ** 2"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYAAAAEZCAYAAACervI0AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nlAlAkmrKBCBJNfX/AXxH+abiQFdBAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x6fa20b8>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "figure()\n",
    "plot(x, y, 'r')\n",
    "xlabel('x')\n",
    "ylabel('y')\n",
    "title('title')\n",
    "show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Most of the plotting related functions in MATLAB are covered by the `pylab` module. For example, subplot and color/symbol selection:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXQAAAEACAYAAACj0I2EAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7001780>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "subplot(1,2,1)\n",
    "plot(x, y, 'r--')\n",
    "subplot(1,2,2)\n",
    "plot(y, x, 'g*-');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The good thing about the pylab MATLAB-style API is that it is easy to get started with if you are familiar with MATLAB, and it has a minumum of coding overhead for simple plots. \n",
    "\n",
    "However, I'd encourrage not using the MATLAB compatible API for anything but the simplest figures.\n",
    "\n",
    "Instead, I recommend learning and using matplotlib's object-oriented plotting API. It is remarkably powerful. For advanced figures with subplots, insets and other components it is very nice to work with. "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## The matplotlib object-oriented API"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The main idea with object-oriented programming is to have objects that one can apply functions and actions on, and no object or program states should be global (such as the MATLAB-like API). The real advantage of this approach becomes apparent when more than one figure is created, or when a figure contains more than one subplot. \n",
    "\n",
    "To use the object-oriented API we start out very much like in the previous example, but instead of creating a new global figure instance we store a reference to the newly created figure instance in the `fig` variable, and from it we create a new axis instance `axes` using the `add_axes` method in the `Figure` class instance `fig`:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYoAAAEgCAYAAACq+TSYAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f9b320>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig = plt.figure()\n",
    "\n",
    "axes = fig.add_axes([0.1, 0.1, 0.8, 0.8]) # left, bottom, width, height (range 0 to 1)\n",
    "\n",
    "axes.plot(x, y, 'r')\n",
    "\n",
    "axes.set_xlabel('x')\n",
    "axes.set_ylabel('y')\n",
    "axes.set_title('title');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Although a little bit more code is involved, the advantage is that we now have full control of where the plot axes are placed, and we can easily add more than one axis to the figure:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYoAAAEgCAYAAACq+TSYAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAIABJREFUeJzt3Xd4VFX+x/H3CU2KILgx9CaiIIHQRIGVKFWkiKIURQQW\nK2LZdXGxgLoq6GJ3UVE04FJWUBGkCoSSH71KWxQlEjABDL0ISc7vjxsiJWVIZuZO+byeZx7CzJ25\nHy4z8805555zjbUWERGRnES4HUBERAKbCoWIiORKhUJERHKlQiEiIrlSoRARkVypUIiISK5UKEQu\ngjGmijHmsDHG5LJNhjGmpj9zifiSCoVIHowxPxtjbgaw1u6y1pa2mROQjDELjTH9z3uKJidJSFGh\nEPG+HFsbIsFIhUIkF8aYcUBVYEZml9NTmV1LEcaYfwJ/Bt7LfOydbJ5f1BjzL2NMojHmV2PMv40x\nxfz97xApCBUKkVxYa+8FfgFutdaWBv5LZteStfZZYAkwKLM7anA2LzESqAXUz/yzEvC8P7KLeIsK\nhYhn8tudNBB4wlp7yFp7DBgB9PJeLBHfK+x2AJFQZYyJBEoAa846SSoCjWFIkFGhEMlbbmcx5fbY\nfuA4cK219lfvRhLxH3U9ieQtGTgzL8Jwbosg5azHzpF5Cu0Y4K3M1gXGmErGmHY+zCridSoUInkb\nATxnjEkF7uDcVsTbwJ3GmN+MMW9l3nf240OAH4HlxpiDwFygth8yi3iN8eWFi4wxlYFxQBSQAXxk\nrX3XGDMMZ5Bvb+amQ621s30WRERE8s3XhaI8UN5au94YUwpYA3QFegBHrLVv+GznIiLiFT4dzLbW\nJuP072KtPWqM2YpzHjnozA8RkaDgtzEKY0x1IAZYkXnXIGPMemPMx8aYMv7KISIiF8enXU9ZO3G6\nneKBl6y10zLPANlvrbWZyyBUsNYOyOZ5WlxNRMTHrLW59vD4vEVhjCkMTAHGW2unZYbaZ/+oUGOA\npjk931qr21m3YcOGuZ4h0G46JjomOiYXeUtJwVatip061aPvcX90PY0Ftlhr3z5zR+Yg9xm3A5v8\nkENERNLSoEcPuOceuP12j57i08FsY0wL4G7ge2PMOpzzy4cCvY0xMTinzO4EHvBlDhERyTRkCBQr\nBi++6PFTfH3WUwJQKJuHNGcin2JjY92OEHB0TC6kY3IhHRNgwgT4+mtYtQoKZffVnD2/DGbnlzHG\nBnI+EZGgsWEDtGkD8+dD/fpZdxtjsG4PZouIiMtSU53xiHffPadIeEotChGRUJaeDh07Qr16MGrU\nBQ+rRSEiEu6ee84502nkyHy/hK5HISISqr780hnAXrUKCuf/615dTyIioWjLFmjVCmbPhsaNc9xM\nXU8iIuHo0CHo1g1efz3XIuEptShEREJJRgbcdhtUrQrvvZfn5p60KDRGISISSv75T+d02ClTvPaS\nKhQiIqFixgz46CNYvRqKFvXay2qMQjxWr149Fi9e7HYMj3Ts2JHx48fn+Hi/fv14/vnn/ZhIxMd+\n+AH694cvvoDy5fPe/iKoUIjHNm3axI033ujXfSYmJhIREUFGRkaO27zwwgvce++959w3c+ZM+vTp\nA0BcXBx//vOffZpTxFVHjzrjEi+9BDfc4PWXV6GQgJWeno619sxgW75f58xriIQka6FfP6dA3H+/\nT3ahQiEeq1GjBgsWLACc3+J79OhB3759KV26NNHR0axduzZr25EjR1K5cmVKly5NnTp1WLhwIeB8\naY8YMYJatWoRGRlJz549OXjwIPBH62Hs2LFUq1aN1q1b06pVK6y1XHbZZZQuXZoVK1ack2nOnDm8\n8sorTJ48mUsvvZSGDRsCcNNNNzF27Fi2bdvGQw89xLJly7j00kspV65ctv+2GTNm0LBhQ8qWLUvL\nli35/vvvvX78RHzitdfgl1+cM5x89AuRCoXk2/Tp0+nduzeHDh2ic+fOPPLIIwBs376d999/nzVr\n1nD48GHmzJlD9erVAXjnnXf45ptvWLJkCXv27KFs2bI8/PDD57zu4sWL2bZtG3PmzGHx4sUYYzh8\n+DCHDx+mWbNm52zbvn17hg4dSo8ePThy5Ajr1q075/FrrrmGDz74gBtuuIEjR46Qmpp6wb9j3bp1\nDBgwgDFjxpCamsoDDzxAly5dOH36tBePlogPzJsHb78NU6fCJZf4bDcqFJJvLVu2pH379hhj6NOn\nDxs3bgSgUKFCnDp1ik2bNpGWlkbVqlWpUaMGAB9++CEvv/wyFSpUoEiRIjz//PNMmTIlawzCGMML\nL7xA8eLFKVasWNa+fDmfZsyYMTz44IM0adIk699SrFgxli9f7rN9ihTYzz9Dnz4wcSJUruzTXalQ\nSL6VP+vMihIlSnDy5EkyMjK48soreeuttxg+fDhRUVH07t2b5ORkwOle6tatG+XKlaNcuXLUrVuX\nIkWKkJKSkvValX38pj9fYmIio0aNyspUtmxZkpKS2LNnj19ziHjs+HFn5vXQoc4yHT6mQiE+0bNn\nT5YsWUJiYiIAQ4YMAaBq1arMmjWL1NRUUlNTOXDgAMeOHaNChQpZzz174NmTQei8tsnr8SpVqvDM\nM8+ck+no0aP06NEjz32L+J21zqB1dDQ8+qhfdqlCIV5zpnto+/btLFy4kFOnTlG0aFGKFy9ORITz\nVnvggQcYOnQov/zyCwD79u3jm2++ueA1zoiMjCQiIoIdO3bkuN+oqCh27tyZY/dUVFQUSUlJOY45\nDBw4kA8++ICVK1cCcOzYMWbOnMmxY8c8/JeL+NE778DmzfDhhz4bvD6fCoV4zNPf3H///Xeefvpp\nIiMjqVixIvv27ePVV18F4LHHHqNr1660a9eOMmXK0Lx586wv6Oz2Ubx4cZ555hlatGhBuXLlztn2\njDvvvBNrLZdffjlNmjS54HVuvvlmrr32WsqXL88VV1xxwfMbN27MmDFjGDRoEOXKlaN27drExcV5\neFRE/GjRInj1VfjqKyhRwm+71aKAHqpevTplypQhIiKCIkWKZPuFJSLiM7t2QbNmEBcHbdt67WW1\nKKAXRUREEB8fT9myZd2OIiLh5uRJuOMOePxxrxYJT6nryUPW2lyXkRAR8Qlr4ZFHoHp1eOopVyKo\nUHjIGEPbtm1p2rQpY8aMcTuOiISLDz+EFStg7Fi/DV6fT11PHkpISKBChQrs27ePtm3bUqdOHVq2\nbJn1uNYSkmAUKGOAkoNly2DYMEhIgFKlXIuhFoWHzpznHxkZSbdu3bIdzLbWBsRt2LBhrmcIpByB\nlMVfOZKPJDNh4wT6f92fqm9WpeKoitz71b2MWz+O3Yd3Y60KRMD79Ve4806nJVGrlqtR1KLwwPHj\nx8nIyKBUqVIcO3aMuXPnMmzYMLdjiWQ5euooixMX891P3zH/5/n8cugXWlVrRZuabXiqxVNcffnV\navUGk1OnnCLxwANw661up1Gh8ERKSgrdunXDGENaWhp333037dq1czuWhLHT6adZuXtlVmFY++ta\nmlZqSpsabfio00c0rtiYwhH6eAetJ56Ayy+HZ55xOwmgQuGRGjVqsH79erdjeCw2NtbtCEDg5IDA\nyZLfHNZaNu/bnFUYFicu5sqyV9KmZhuevfFZWlZtSYki/puAJT702Wcwf74zgB0RGKMDmnDnJQW9\nuI7I+XYd2sX8n+dnFYcSRUrQpkYb2tRsw001buJPJf5UoNfXezYArV4NHTs6M7Dr1PHLLj2ZcKdC\n4SX60ElBHThxgPid8Xz303d89/N3pJ5IpXWN1rSp2YbWNVpTo2wNr+5P79kAs3cvNG0Kb74Jt9/u\nt92qUPiRPnRysU6mneT/dv2fUxh++o5t+7fRomqLrOJQP6o+EcZ3XQ96zwaQtDRnxnXz5vDyy37d\ntQqFH+lDJ3lJz0hnffL6rBbD8qTlRF8RnVUYrq98PcUKF8v7hbxE79kA8te/OivCfvstFCrk112r\nUPiRPnSSnX3H9jHrx1nM2D6D+T/PJ6pkFG1qOuMMraq1oswlZVzLpvdsgJg4EZ59Flatghyu6e5L\nKhR+pA+dgHN20pZ9W5i+fTrTt09n095NtKnZhk5XdaJ9rfZUvLSi2xGz6D0bADZsgDZtnLOc6td3\nJYIKhR/pQxe+TqWfYtHORUzfPp0Z22eQbtPpXLsznWt3JrZ6rF+7ky6G3rMuS011Bq9ffhl69nQt\nhgqFH+lDF172HdvHzB9mMuOHGczbMY86kXWyikO9K+oFxSxovWddlJ7uzLiuVw/+9S9Xo7heKIwx\nlYFxQBSQAYyx1r5jjCkLTAaqATuBu6y1h7J5fsAUioyMDJo0aULlypXPuXTnGfrQhbacupQ61+5M\nx6s6ckXJC6+cF+j0nnXR0KHOhLo5c6Cwu/OeA+HCRWnAk9ba9caYUsAaY8xcoB/wnbX2NWPMEOAf\nwNM+zlIgb7/9NnXr1uXw4cNuRxE/Ob9LKcNm0Ll2Z56/8fmA7lKSAPfllzBhgjN47XKR8JRPU1pr\nk4HkzJ+PGmO2ApWBrkCrzM3igHgCuFAkJSUxc+ZMnnnmGd544w2344gP5dSlNK3ntKDpUpIAtmUL\nPPggzJoFkZFup/GY38qZMaY6EAMsB6KstSngFBNjTEC325944glef/11Dh26oHdMgtz5XUqb926m\ndc3WdK7dmfc7vh+UXUoSoA4dgm7d4LXXoHFjt9NcFL8UisxupynAY5kti/M7RnPsKB0+fHjWz7Gx\nsX5f3O3bb78lKiqKmJgY4uPjc+3TdTureCanLqVhrYbRqlqrkO1Sio+PJz4+3u0Y4SkjA/r0cWZf\n33efq1Hy8z7w+VlPxpjCwAxglrX27cz7tgKx1toUY0x5YKG19oIVsAJhMHvo0KF8/vnnFC5cmBMn\nTnDkyBFuv/12xo0bd852GhgMbPuP72fmDzOZvn0683bMo25kXTrV7hRUZyl5m96zfvTiizB3LixY\nAEWLup3mHK6f9ZQZYhyw31r75Fn3jQRSrbUjMwezy1prLxijCIRCcbZFixYxatQonfUUJA6dPMRX\n275i0qZJLE9antWlFKxnKXmb3rN+8vXX8OijzuB1+fJup7mA62c9GWNaAHcD3xtj1uF0MQ0FRgL/\nNcb0BxKBu3yZQ8LH8dPHmbF9BhM3TWTBzwu4ucbN9G/Yny97fKnrNYj/JSTA/ffDzJkBWSQ8pQl3\nXqLfztxzKv0Uc36cw6TNk/h2+7c0q9yMXvV60e2abq6upRTo9J71sc2b4eabYfx4COArYgZE11NB\nqFBITtIz0onfGc+kTZP4ctuX1I2sS696vehet7u6lTyk96wPJSVBixbwyitw991up8mV611PIt5k\nrWV50nImbprIF1u+oNKllehZryfrH1hPlTJV3I4n4jhwADp0gMGDA75IeEotCi/Rb2e+Ya1lY8pG\nJm6ayKRNkyhepDi96vWiZ72e1L68ttvxgpresz5w4oTTzXTddTBqlNtpPKKuJz/Sh867tv+2nUmb\nJjFx00ROpp2k57U96VmvJ/Wj6oflqay+oPesl6WnQ/fuUKKEMy4R4burE3qTup4kqOw6tIvJmycz\ncdNE9hzZw11172Jsl7FcX/l6FQcJbNbCI4/A0aMweXLQFAlPqVCIq/Ye28uULVOYuGkiW/Zt4fZr\nbue1Nq8RWz2WQhH+vSSkSL699JIzTyI+PuAm1HmDCoX43cm0k0zZMoXxG8ezImkFt9a+lb83/zvt\na7WnaKHQ+5BJiPvoIxg3zpkzcemlbqfxCY1ReIn6e/P2Y+qPfLj6Qz7b8BmNKjSif0x/OtXuRMmi\nJd2OFpb0nvWCadPgoYdg8WKoVcvtNPmiMQpxXVpGGtP/N50P1nzAul/XcV/MfSwbsIxa5YLzQyWS\nJSEBBg50Zl0HaZHwlFoUHvj999+58cYbOXXqFGlpaXTv3p1hw4ads41+OzvX7sO7+Xjtx4xZO4Zq\nl1XjoSYP0b1udy4pfInb0SST3rMFECSzrj2hFoWXFCtWjIULF1KiRAnS09Np0aIFt9xyC9ddd53b\n0QJKhs1g/k/zGb16NPE74+lZrycz755J/aj6bkcT8Z6kJOjYEd54I+iLhKdUKDxUooSzoNzvv/9O\nWlqaTtc8y2/Hf+PT9Z/y4ZoPKVGkBA81eYi42+K4tFhoDuxJGAvBWdeeUKHwUEZGBo0bN2bHjh08\n8sgjNG3a1O1IrjqznMbo1aP55n/f0OXqLoy7bZzmPEjoOnECunSB9u3hr391O41fqVB4KCIignXr\n1nH48GFuu+02tmzZQt26dc/ZJhyucHfk9yP85/v/8MHqDzh2+hgPNn6QN9u/yeUlLnc7muRBV7gr\ngLQ06N0bqlaF1193O43faTA7H1566SVKlizJk09mXYsp5AcGN6Zs5IPVHzBp0yRuqnETDzZ+kNY1\nWxNhQmsGajgJ9fes11gLDz4IP/0E334bchPqNJjtJfv376dIkSKUKVOGEydOMG/ePJ5++oIL8oWc\nMxPjRq8eTeLBRAY2Gsj3D31PpdKV3I4m4j8vvQSrV4fsrGtPqFB44Ndff6Vv375kZGSQkZFBjx49\n6Nixo9uxfObI70d4f9X7vLn8TWLKx/BU86foVLsThSP0dpEwEwazrj2hricvCYVm/JkC8cayN2hT\nsw3P3vgsdSPr5v1ECUqh8J71qRCYde0JdT2JR84vEIvuW0SdyDpuxxJxTxjNuvaECkUYU4EQycbm\nzXD77fD559CkidtpAkLYnLKyZcuWC+4L11MFj/x+hBFLR3DlO1eyMWUji+5bxIQ7JqhIiOzaBbfc\nElazrj0RNoXirrvuYuTIkVhrOXHiBI8++ij/+Mc/3I7lVyoQIrk4M+v6scfCata1J8KmUKxYsYJd\nu3bRvHlzmjZtSsWKFUlISHA7ll+oQIjk4cys6w4dwm7WtSfCZoyiSJEiFC9enBMnTnDy5Elq1KhB\nRIhdrvB8GoMQ8UCYz7r2RGh/U56ladOmFC9enFWrVrFkyRImTpzInXfe6XYsn1ALQsRDZ1/r+tNP\nQ+5a194SNi2KTz75hCaZZzBUqFCBadOmMX78eJdTedfx08d5Z8U7akGIeOrFF8N+1rUnNOHOA0lJ\nSdx7772kpKQQERHBwIEDGTx48DnbuD15acHPC7h/+v3ElI/hpZteUoGQPLn9nnXdRx/Ba685cyai\notxO4xpPJtypUHggOTmZ5ORkYmJiOHr0KI0bN2batGlcc801Wdu49aE7cOIAT817ijk75vDvjv+m\n89Wd/Z5BglNYF4owmXXtCU8KhTrkPFC+fHliYmIAKFWqFHXq1GH37t0up4KpW6ZSb3Q9ihUqxuaH\nN6tIiHjizKzrb74J+yLhqbAZo/CWnTt3sn79epo1a+Zahj1H9jBo5iC27NvC5O6TaVm1pWtZRIKK\nZl3niwrFRTh69Cjdu3fn7bffplSpUhc87usLF2XYDD5Z+wlDFwzlwcYPMuGOCVxS+BKv7kNCV9hf\nuEizrvNNYxQeSktLo1OnTtxyyy089thjFzzu6/7eH377gftn3M+xU8f4uMvH1I+q77N9SXgIqzGK\nAwegZUvo318T6s6jMQov6t+/P3Xr1s22SPjS6fTTjFg6ghs+uYEutbuwbMAyFQmRi6FZ1wWmFoUH\nEhISuPHGG4mOjsYYgzGGV155hQ4dOmRt44vfztb+upYB3wwgskQkH3b6kBpla3j19SW8hUWLIi0N\nuneHkiVh/HhNqMuGTo/1I29+6I6fPs7w+OHEbYjj9bav06d+H4zJ9f9R5KKFfKEI8Wtde4suXBSE\nvk/5nm6Tu9GkYhM2PriRqFLhOxFIpEA069prVCgCyOLExXT/b3febP8md9fXMsci+fbRR05XU5hf\n69pbfNphZ4z5xBiTYozZeNZ9w4wxScaYtZm3Drm9RriYumUq3f/bnQl3TFCRECmIr7+G4cNh9uyw\nXprDm3w9svMp0D6b+9+w1jbKvM32cYaAN3rVaAbPHsyce+bQpmYbt+OIBK+lS+H++zXr2st82vVk\nrV1qjKmWzUMamQWstTy/8HkmbZ7Ekn5LqFm2ptuRRILX5s1wxx2ade0Dbp0rNsgYs94Y87ExpoxL\nGVyVlpHGX775C7N3zCahf4KKhEhBbN0K7dvDqFGade0DbhSKfwM1rbUxQDLwhgsZXHX89HG6Te7G\n7iO7Wdh3IVeUvMLtSCLBa8MGaN0aXn0V7rnH7TQhye9nPVlr95311zHA9Ny29/X6Sf722/Hf6DSx\nE7XK1eKTLp9QtJBO2xPJt9WroVMnePddCNErVnpbftb88vmEO2NMdWC6tTY68+/lrbXJmT8/ATS1\n1vbO4bkBMeFuwIABzJgxg6ioKDZu3JjtNp5MXko8mEj7z9vT5eoujGgzggijWaLinqCfcJeQAN26\nwccfO0t0SL64vtaTMWYC8H9AbWPML8aYfsBrxpiNxpj1QCvgCV9m8IZ+/foxZ86cAr3G9ynf0/LT\nljzQ+AFea/uaioRIQSxYALfd5gxcq0j4nJbw8FBiYiKdO3fOV4ti//H91B9dn1HtRtErupcvY4p4\nLGhbFLNmQd++8MUX0KqV22mCnustCnEMmjmIXvV6qUiIFNRXX8F99zmXMlWR8Bst4eFF2Q28T90y\nlbW/rmVs17HuBRMhBC5cNGkSPP6406Jo1MjtNGFFXU8eyk/X0/7j+4keHc2UO6fQomoLf8QU8VhQ\ndT199hkMHQpz50K9em6nCSlaPdaLrLUX/aEaNHMQvev1VpEQKYjRo+GVV2DhQrj6arfThCWNUXig\nd+/eNG/enO3bt1O1alU+/fTTPJ8zdctU1iWv4583/9MPCUVC1JtvwmuvwaJFKhIuUteTl5zdjFeX\nkwSDgO96evlliIuD+fOhShW304QsdT25RF1OIgVgLTz3nHOG06JFUKGC24nCngqFl53pcvq0a97d\nUyJyHmvhb39zJtTFx0NkpNuJBBUKrzpw4gCDZg1i6l1TKV6kuNtxRIJLRgYMGgRr1jiFomxZtxNJ\nJhUKL5qzYw7XVbqO5lWaux1FJLikp8Nf/gI//gjz5kHp0m4nkrOoUHjRsl3LaFFF4xIiF+X0aejT\nB/bvdy5fWrKk24nkPDo91ouWJS3jhso3uB1DJHj8/jvcdRccPQozZqhIBCgVCi/avG8zTSrqEowi\nHjlxwlkBtlAh+PJLuOQStxNJDlQovKhuZF0NYot44uhRuPVWKFfOWcOpqC7gFchUKDwwe/Zsrrnm\nGmrXrs3IkSNz3O76Stf7MZVIkDp0CDp0gJo1Ydw4KKyh0kCnQpGHjIwMBg0axJw5c9i8eTMTJ05k\n27Zt2W57Q5XAGJ8IlBVCAyUHBE6WQMnhmtRUaNMGYmLgo4+cbicJeCoUeVi5ciVXXXUV1apVo0iR\nIvTs2ZNp06Zlu22gDGQHypdRoOSAwMkSKDlcsXcv3HQTxMY617iO0NdPsMjzf8oY86gxJmxnvuze\nvZsqZ60zU7lyZXbv3p3tttUvq+6nVCJBZs8e50JDt93mLPJncl1aSAKMJyU9ClhljPmvMaaDMfof\nzokOjUg2EhPhxhudy5e+8IKKRBDyaPXYzOLQDugHNAH+C3xird3h03ABsHrs8uXLGT58OLNnzwZg\nxIgRGGMYMmTIOdupSEgw8vnna8cOaN0annwSBg/27b4kX7y2eqy11hpjkoFkIA0oC0wxxsyz1v69\n4FEDV9OmTfnxxx9JTEykQoUKTJo0iYkTJ16wndsFTSTgbN0K7do5K8Hef7/baaQA8iwUxpjHgHuB\n/cDHwFPW2tPGmAjgByCkC0WhQoV47733aNeuHRkZGQwYMIA6deq4HUsksG3YALfcAiNHOstzSFDL\ns+vJGPMCMNZam5jNY3WstVt9Fi4Aup5E5CKtXg2dOjlnNt15p9tpJA+edD3lOZhtrR2WXZHIfMxn\nRSKYeDohz9eqV69OgwYNaNiwIdddd51f9z1gwACioqKoX79+1n0HDhygXbt2XH311bRv355Dhw65\nluWFF16gcuXKNGrUiEaNGmWNOflSUlISN998M9deey3R0dG88847gP+Py/k53n33XcBHxyQhATp2\ndOZIqEiEDmttwN6ceIEtPT3dXnnllXbnzp321KlTtkGDBnbr1q2uZKlRo4ZNTU11Zd9Lliyx69at\ns9HR0Vn3/f3vf7cjR4601lo7YsQIO2TIENeyDB8+3I4aNcov+z/j119/tevWrbPWWnvkyBFbu3Zt\nu3XrVr8fl5xyeP2YLFhgbWSktXPmeO81xecyv2dz/S7WjJcCupgJeb5mrSUjI8OVfbds2ZKy511o\nZtq0afTt2xeAvn378vXXX7uWBfx/wkH58uWJiYkBoFSpUtSpU4ekpCS/H5fscpyZC+S1YzJ7NvTo\nAV984QxgS0hRoSigi5mQ52vGGNq2bUvTpk0ZM2aMKxnOtnfvXqKiogDny2rv3r2u5nnvvfeIiYnh\nL3/5i9+6wc7YuXMn69ev5/rrryclJcW143ImR7NmzQAvHZOvv3bmSEyb5kyqk5CjQhFCEhISWLt2\nLTNnzuT9999n6dKlbkc6h5tzTR5++GF++ukn1q9fT/ny5XnyySf9tu+jR4/SvXt33n77bUqVKnXB\ncfDXcTk/h1eOyeTJ8OCDMGsW3BAYS9iI96lQFFClSpX45Zdfsv6elJREpUqVXMlSoUIFACIjI+nW\nrRsrV650JccZUVFRpKSkAJCcnMwVV1zhWpbIyMisL+SBAweyatUqv+w3LS2N7t2706dPH7p27Qq4\nc1yyy1HgY/LZZ/DEE86lSxs18nJiCSQqFAV09oS8U6dOMWnSJLp06eL3HMePH+fo0aMAHDt2jLlz\n51KvXj2/ZrB/nIQAQJcuXfjss88AiIuLy/qCciNLcnJy1s9ffvml345N//79qVu3Lo899ljWfW4c\nl+xyFOiYfPCBM5Fu4UKIjvZmVAlEeY12u3kjCM56stbaWbNm2dq1a9tatWrZV1991ZUMP/30k23Q\noIGNiYmx9erV83uOXr162QoVKtiiRYvaKlWq2LFjx9rU1FTbunVrW7t2bdu2bVt74MAB17L06dPH\nRkdH2wY4vuLLAAAOWUlEQVQNGtiuXbva5ORkn+dYunSpjYiIyPp/adiwoZ01a5b97bff/HpccsqR\n72Py5pvWVq9u7Y4dPs0t/oEHZz15tNaTWzThTiSApKXBkCHOta2/+w7OOolDgpfX1noSkTB34IBz\n+qsxsHw5ZHP6sYQujVGISO62bIHrrnPGIr79VkUiDKlQiEjOvvnGmRvx3HMwapSubx2m9L8uIhey\nFl55BUaPdsYkMifoSXhSoRCRcx07Bv36wS+/wMqVULGi24nEZT7tejLGfGKMSTHGbDzrvrLGmLnG\nmP8ZY+YYY8r4MoOIXITERGjZEkqUgPh4FQkBfD9G8SnQ/rz7nga+s9ZeDSwA/uHjDCLiicWL4frr\nnXWbPv0ULrnE7UQSIHxaKKy1S4ED593dFYjL/DkOuM2XGUTEAx984Fw/Ytw4ePxx5zRYkUxujFFc\nYa1NAbDWJhtj3FsASALWsGHDKFeuXNaSE88++yxRUVE8+uijLicLMadOweDBTmsiIQFq1XI7kQQg\nn8/MNsZUA6Zba+tn/j3VWlvurMd/s9ZensNzNTM7TCUmJnL77bezZs0arLVcddVVrFq1KtvrTEg+\n7d0L3bvDZZfB559D6dJuJxIXBOrM7BRjTJS1NsUYUx7IdTH+4cOHZ/0cGxtLbGysb9NJQKhWrRp/\n+tOf2LBhA8nJyTRq1EhFwpvWrYNu3aBPH3jhBYjQlKpwER8fT3x8/EU9xx8tiuo4LYrozL+PBFKt\ntSONMUOAstbap3N4rloUYeyLL74gISGB5ORk7rvvPjp06OB2pNAweTIMGgT//reuay0etSh8WiiM\nMROAWOByIAUYBnwNfAFUARKBu6y1B3N4vgpFGDt9+jTR0dGkpaXxww8/uHrho5CQkeHMsP7Pf5yr\n0mVeHlXCm+tdT9ba3jk81MaX+5XQUKRIEW666SbKli2rIlFQhw/DPffAoUOwahVERrqdSIKIOiYl\nYGVkZLB8+XIGDBjgdpTg9sMPzvyISpWcq9GpSMhFUqGQgLR161auuuoq2rZty5VXXul2nOA1d64z\n03rwYGfdpqJF3U4kQUgXLhIJRdbCm2/C6687g9c33uh2IglQro9RiIgLTp6EBx6AjRudiwxVq+Z2\nIgly6noSCSV79jjXjzh5EpYuVZEQr1ChEAkVy5c7V6Lr2hUmTYKSJd1OJCFCXU8ioSAuDv72Nxg7\nFjp3djuNhBgVCpFglpYGTz3lXIVu0SKoW9ftRBKCVChEglVqKvTs6fy8YgWUK5f79iL5pDEKkWC0\nebMzHhEdDTNnqkiIT6lQiASbadMgNhaefx5GjYLC6hgQ39I7TCRYWAsvv+xcjW7GDGjWzO1EEiZU\nKESCwbFj0K8fJCbCypVQsaLbiSSMqOtJJNAlJkKLFlC8uHNmk4qE+JkKhUggW7TIWfn1vvvgs8/g\nkkvcTiRhSF1PIoFq9GgYPty5nnXbtm6nkTCmQiESaA4ehMcfd8YiEhKgVi23E0mYU9eTSCCZNcuZ\nG1G8uDOJTkVCAoBaFCKB4OBBePJJWLjQGYto3drtRCJZ1KIQcduZVkSxYs41JFQkJMCoRSHiFrUi\nJEioRSHiBrUiJIioRSHiT2pFSBBSi0LEX9SKkCClFoWIr6kVIUFOLQoRX1IrQkKAWhQivnDwIPz1\nr7BggVoREvTUohDxtjOtiKJF1YqQkKAWhYi3qBUhIUotChFvUCtCQphaFCIFoVaEhAG1KETyS60I\nCRNqUYhcLLUiJMyoRSFyMdSKkDCkFoWIJ9SKkDCmFoVIXtSKkDCnFoVITtSKEAHUohDJnloRIllc\na1EYY3YCh4AM4LS19jq3sohkUStC5AJutigygFhrbUMVCQkIakWIZMvNMQqDur4kEKgVIZIrN7+o\nLTDPGLPKGDPQxRwSztSKEMmTmy2KFtbaX40xkTgFY6u1dun5Gw0fPjzr59jYWGJjY/2XUELXihXw\n7LPw889qRUhYiY+PJz4+/qKeY6y1vklzMSGMGQYcsda+cd79NhDySQjZsAGeew7WrXP+7NcPihRx\nO5WIa4wxWGtNbtu40vVkjClhjCmV+XNJoB2wyY0sEib+9z/o2RM6dHBaDz/8APffryIh4gG3xiii\ngKXGmHXAcmC6tXauS1kklO3c6bQaWraEBg2cAvHYY3DJJW4nEwkaroxRWGt/BmLc2LeEiT174J//\nhMmT4ZFHnAJx2WVupxIJSjo9VULL/v3wt79BvXpQogRs2wYvvqgiIVIAKhQSGg4ehOefh6uvhhMn\nYNMm+Ne/IDLS7WQiQU+FQoLbsWPw6qtw1VWQlARr1sD770PFim4nEwkZKhQSnE6ehLfegiuvdE55\nXboUxo6F6tXdTiYScrTMuASX06fh00/hpZegUSOYOxfq13c7lUhIU6GQ4JCeDhMmwPDhULMmTJkC\nzZq5nUokLKhQSGDLyICvvnIGqi+7DD75BLSMi4hfqVBIYLLWWbDv2WfBGOcMpg4dnJ9FxK9UKCTw\nxMfDM884p7y+9BJ066YCIeIiFQoJHGev6Dp8OPTqBYUKuZ1KJOzp9Fhx34YN0KUL3Hkn3HUXbN0K\n99yjIiESIFQoxD3btkGPHn+s6Lp9OwwcqBVdRQKMCoX435kVXf/8Z2jYEH78USu6igQwFQrxnz17\n4OGHoXFjqFLFWdH16aehZEm3k4lILlQoxPd273ZWdI2OdoqCVnQVCSo660l84/hxZ6JcXBysXg13\n3w3ff6/F+kSCkAqFeE9GhrM4X1wcfPklXH899O8P06ZB8eJupxORfFKhkILbsQPGjYPx452upb59\nYcsWqFDB7WQi4gUqFJI/hw7BF184rYf//c+ZHDdlinMWk2ZRi4QUY611O0OOjDE2kPOFnfR0mDfP\nKQ6zZjlzH/r2hVtu0dwHkSBljMFam+tvdyoUkrdNm5yupc8/d05rvfde6NkTLr/c7WQiUkCeFAp1\nPUn29u2DiROd1kNKCvTpA/PnQ506bicTET9Ti0L+cOoUfPutUxzi46FzZ6f1cPPNWndJJESp60ny\nZq0zzyEuDiZPhmuvdcYduneHSy91O52I+Ji6niRnu3c7Yw5xcU5L4t57YeVKqFHD7WQiEmBUKMLJ\n+bOlu3eHMWOgeXOd0ioiOVKhCHUZGbBkiXPWkmZLi0g+qFCEqjOzpceNg1KlNFtaRPJNhSKUHDzo\nzI6Oi3MuAtSrF0ydqtnSIlIgOuspWFnrXM9h2bI/bjt2QPv2mi0tIh7T6bGh5MgR56ykZctg+XLn\nVrIk3HDDH7eYGCha1O2kIhJEVCiCVU6thZgYZzD6TGHQtR1EpIBUKILFkSOwatUfRUGtBRHxExWK\nQJRda+HHH51CcHZhUGtBRPxAhSIQqLUgIgFMhcLf1FoQkSCjQuFrai2ISJAL6EJhjOkAvAVEAJ9Y\na0dms417heL4cfjtt+xvu3Y5RcGF1kJ8fDyxsbE+3Uew0TG5kI7JhXRMshewq8caYyKA94DWwB5g\nlTFmmrV2m9d3lp4OBw7k/KWf3S011Xnu5Zdnf4uOdtZLatjQ760FvdkvpGNyIR2TC+mY5J9bS3hc\nB/xgrU0EMMZMAroCuReK3H7Lz+l2+DCUKZPzl37Vquf+vVw5588SJXx/FEREgoBbhaISsOusvyfh\nFI8LNWjwx5c+5PyFX6WK0w10/v2XXaars4mIFIArYxTGmDuA9tba+zP/fg9wnbV28HnbBfBItohI\naAjIMQpgN1D1rL9XzrzvHHmFFxER34twab+rgFrGmGrGmKJAT+Abl7KIiEguXGlRWGvTjTGDgLn8\ncXrsVjeyiIhI7gJ6wp2IiLjPra6nXBljOhhjthljthtjhridJxAYYz4xxqQYYza6nSVQGGMqG2MW\nGGM2G2O+N8YMzvtZoc0YU8wYs8IYsy7zmAxzO1OgMMZEGGPWGmPUzQ0YY3YaYzZkvldW5rptoLUo\nMifjbeesyXhAT59MxgsixpiWwFFgnLW2vtt5AoExpjxQ3lq73hhTClgDdNV7xZSw1h43xhQCEoDB\n1tpcvwjCgTHmCaAxUNpa28XtPG4zxvwENLbWHshr20BsUWRNxrPWngbOTMYLa9bapUCe/6HhxFqb\nbK1dn/nzUWArzhydsGatPZ75YzGcccjA+m3QBcaYykBH4GO3swQQg4c1IBALRXaT8cL+wy+5M8ZU\nB2KAFe4mcV9mF8s6IBmYZ61d5XamAPAm8BQqmmezwDxjzCpjzMDcNgzEQiFyUTK7naYAj2W2LMKa\ntTbDWtsQZ35SM2NMXbczuckYcyuQktn6NJk3gRbW2kY4La1HMru3sxWIhcKjyXgiAMaYwjhFYry1\ndprbeQKJtfYwsBDo4HYWl7UAumT2yU8EbjLGjHM5k+ustb9m/rkP+IqcllEiMAuFJuPlTL8NXWgs\nsMVa+7bbQQKBMeZPxpgymT8XB9qS12KbIc5aO9RaW9VaWxPn+2SBtfZet3O5yRhTIrMljjGmJNAO\n2JTT9gFXKKy16cCZyXibgUmajAfGmAnA/wG1jTG/GGP6uZ3JbcaYFsDdwM2Zp/itzbzOSTirACw0\nxqzHGa+ZY62d6XImCTxRwNLMsazlwHRr7dycNg6402NFRCSwBFyLQkREAosKhYiI5EqFQkREcqVC\nISIiuVKhEBGRXKlQiIhIrlQoREQkVyoUIiKSKxUKkQIyxjTJvABMUWNMSWPMpnBfiE9Ci2Zmi3iB\nMeZFoHjmbZe1dqTLkUS8RoVCxAuMMUVwFrQ8ATS3+mBJCFHXk4h3/AkoBVwKXOJyFhGvUotCxAuM\nMdNwrnVQA6horX3U5UgiXlPY7QAiwc4Y0wc4Za2dZIyJABKMMbHW2niXo4l4hVoUIiKSK41RiIhI\nrlQoREQkVyoUIiKSKxUKERHJlQqFiIjkSoVCRERypUIhIiK5+n9k32bW2QGjlQAAAABJRU5ErkJg\ngg==\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x72d0470>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig = plt.figure()\n",
    "\n",
    "axes1 = fig.add_axes([0.1, 0.1, 0.8, 0.8]) # main axes\n",
    "axes2 = fig.add_axes([0.2, 0.5, 0.4, 0.3]) # inset axes\n",
    "\n",
    "# main figure\n",
    "axes1.plot(x, y, 'r')\n",
    "axes1.set_xlabel('x')\n",
    "axes1.set_ylabel('y')\n",
    "axes1.set_title('title')\n",
    "\n",
    "# insert\n",
    "axes2.plot(y, x, 'g')\n",
    "axes2.set_xlabel('y')\n",
    "axes2.set_ylabel('x')\n",
    "axes2.set_title('insert title');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "If we don't care about being explicit about where our plot axes are placed in the figure canvas, then we can use one of the many axis layout managers in matplotlib. My favorite is `subplots`, which can be used like this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYAAAAEZCAYAAACervI0AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nlAlAkmrKBCBJNfX/AXxH+abiQFdBAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x8065710>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots()\n",
    "\n",
    "axes.plot(x, y, 'r')\n",
    "axes.set_xlabel('x')\n",
    "axes.set_ylabel('y')\n",
    "axes.set_title('title');"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYAAAAEZCAYAAACervI0AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nUqZUAYiIlClVACIiZer/ATIsl5DbY4t8AAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x8498390>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots(nrows=1, ncols=2)\n",
    "\n",
    "for ax in axes:\n",
    "    ax.plot(x, y, 'r')\n",
    "    ax.set_xlabel('x')\n",
    "    ax.set_ylabel('y')\n",
    "    ax.set_title('title')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "That was easy, but it isn't so pretty with overlapping figure axes and labels, right?\n",
    "\n",
    "We can deal with that by using the `fig.tight_layout` method, which automatically adjusts the positions of the axes on the figure canvas so that there is no overlapping content:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAakAAAEbCAYAAABgLnslAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nSkREIuv/AQVSRBlr/kglAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x892eb70>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots(nrows=1, ncols=2)\n",
    "\n",
    "for ax in axes:\n",
    "    ax.plot(x, y, 'r')\n",
    "    ax.set_xlabel('x')\n",
    "    ax.set_ylabel('y')\n",
    "    ax.set_title('title')\n",
    "    \n",
    "fig.tight_layout()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Saving figures"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "To save a figure to a file we can use the `savefig` method in the `Figure` class:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "fig.savefig(\"filename.png\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### What formats are available and which ones should be used for best quality?"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Matplotlib can generate high-quality output in a number formats, including PNG, JPG, EPS, SVG, PGF and PDF. For scientific papers, I recommend using PDF whenever possible. (LaTeX documents compiled with `pdflatex` can include PDFs using the `includegraphics` command). In some cases, PGF can also be good alternative."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Legends, labels and titles"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now that we have covered the basics of how to create a figure canvas and add axes instances to the canvas, let's look at how decorate a figure with titles, axis labels, and legends."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Figure titles**\n",
    "\n",
    "A title can be added to each axis instance in a figure. To set the title, use the `set_title` method in the axes instance:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "ax.set_title(\"title\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Axis labels**\n",
    "\n",
    "Similarly, with the methods `set_xlabel` and `set_ylabel`, we can set the labels of the X and Y axes:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "ax.set_xlabel(\"x\")\n",
    "ax.set_ylabel(\"y\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Legends**\n",
    "\n",
    "Legends for curves in a figure can be added in two ways. One method is to use the `legend` method of the axis object and pass a list/tuple of legend texts for the previously defined curves:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "ax.legend([\"curve1\", \"curve2\", \"curve3\"]);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The method described above follows the MATLAB API. It is somewhat prone to errors and unflexible if curves are added to or removed from the figure (resulting in a wrongly labelled curve).\n",
    "\n",
    "A better method is to use the `label=\"label text\"` keyword argument when plots or other objects are added to the figure, and then using the `legend` method without arguments to add the legend to the figure: "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "ax.plot(x, x**2, label=\"curve1\")\n",
    "ax.plot(x, x**3, label=\"curve2\")\n",
    "ax.legend();"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The advantage with this method is that if curves are added or removed from the figure, the legend is automatically updated accordingly.\n",
    "\n",
    "The `legend` function takes an optional keyword argument `loc` that can be used to specify where in the figure the legend is to be drawn. The allowed values of `loc` are numerical codes for the various places the legend can be drawn. See http://matplotlib.org/users/legend_guide.html#legend-location for details. Some of the most common `loc` values are:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "<matplotlib.legend.Legend at 0x3dfc1d0>"
      ]
     },
     "execution_count": 22,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "ax.legend(loc=0) # let matplotlib decide the optimal location\n",
    "ax.legend(loc=1) # upper right corner\n",
    "ax.legend(loc=2) # upper left corner\n",
    "ax.legend(loc=3) # lower left corner\n",
    "ax.legend(loc=4) # lower right corner\n",
    "# .. many more options are available"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The following figure shows how to use the figure title, axis labels and legends described above:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYYAAAEZCAYAAACTsIJzAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nICIiBSgxiIhIAUoMIiJSgBKDiIgU8P8BSBXVKQeTtDcAAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x6feab00>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots()\n",
    "\n",
    "ax.plot(x, x**2, label=\"y = x**2\")\n",
    "ax.plot(x, x**3, label=\"y = x**3\")\n",
    "ax.legend(loc=2); # upper left corner\n",
    "ax.set_xlabel('x')\n",
    "ax.set_ylabel('y')\n",
    "ax.set_title('title');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Setting colors, linewidths, linetypes"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### Colors"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "With matplotlib, we can define the colors of lines and other graphical elements in a number of ways. First of all, we can use the MATLAB-like syntax where `'b'` means blue, `'g'` means green, etc. The MATLAB API for selecting line styles are also supported: where, for example, 'b.-' means a blue line with dots:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 32,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[<matplotlib.lines.Line2D at 0x96df0b8>]"
      ]
     },
     "execution_count": 32,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# MATLAB style line color and style \n",
    "ax.plot(x, x**2, 'b.-') # blue line with dots\n",
    "ax.plot(x, x**3, 'g--') # green dashed line"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We can also define colors by their names or RGB hex codes and optionally provide an alpha value using the `color` and `alpha` keyword arguments:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[<matplotlib.lines.Line2D at 0x6fbc048>]"
      ]
     },
     "execution_count": 33,
     "metadata": {},
     "output_type": "execute_result"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAWwAAAEFCAYAAADHZN0rAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\niEhCaGCLiCSEBraISEL8f0xRDuTFV1stAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x984b550>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots()\n",
    "\n",
    "ax.plot(x, x+1, color=\"red\", alpha=0.5) # half-transparant red\n",
    "ax.plot(x, x+2, color=\"#1155dd\")        # RGB hex code for a bluish color\n",
    "ax.plot(x, x+3, color=\"#15cc55\")        # RGB hex code for a greenish color"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### Line and marker styles"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "To change the line width, we can use the `linewidth` or `lw` keyword argument. The line style can be selected using the `linestyle` or `ls` keyword arguments:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 34,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAsMAAAF0CAYAAADGqzQSAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nYUIIIYQQkrD8PwrfSAJV3mn5AAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x891f0f0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(figsize=(12,6))\n",
    "\n",
    "ax.plot(x, x+1, color=\"blue\", linewidth=0.25)\n",
    "ax.plot(x, x+2, color=\"blue\", linewidth=0.50)\n",
    "ax.plot(x, x+3, color=\"blue\", linewidth=1.00)\n",
    "ax.plot(x, x+4, color=\"blue\", linewidth=2.00)\n",
    "\n",
    "# possible linestype options ‘-‘, ‘--’, ‘-.’, ‘:’, ‘steps’\n",
    "ax.plot(x, x+5, color=\"red\", lw=2, linestyle='-')\n",
    "ax.plot(x, x+6, color=\"red\", lw=2, ls='-.')\n",
    "ax.plot(x, x+7, color=\"red\", lw=2, ls=':')\n",
    "\n",
    "# custom dash\n",
    "line, = ax.plot(x, x+8, color=\"black\", lw=1.50)\n",
    "line.set_dashes([5, 10, 15, 10]) # format: line length, space length, ...\n",
    "\n",
    "# possible marker symbols: marker = '+', 'o', '*', 's', ',', '.', '1', '2', '3', '4', ...\n",
    "ax.plot(x, x+ 9, color=\"green\", lw=2, ls='--', marker='+')\n",
    "ax.plot(x, x+10, color=\"green\", lw=2, ls='--', marker='o')\n",
    "ax.plot(x, x+11, color=\"green\", lw=2, ls='--', marker='s')\n",
    "ax.plot(x, x+12, color=\"green\", lw=2, ls='--', marker='1')\n",
    "\n",
    "# marker size and color\n",
    "ax.plot(x, x+13, color=\"purple\", lw=1, ls='-', marker='o', markersize=2)\n",
    "ax.plot(x, x+14, color=\"purple\", lw=1, ls='-', marker='o', markersize=4)\n",
    "ax.plot(x, x+15, color=\"purple\", lw=1, ls='-', marker='o', markersize=8, markerfacecolor=\"red\")\n",
    "ax.plot(x, x+16, color=\"purple\", lw=1, ls='-', marker='s', markersize=8, \n",
    "        markerfacecolor=\"yellow\", markeredgewidth=2, markeredgecolor=\"blue\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Control over axis appearance"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The appearance of the axes is an important aspect of a figure that we often need to modify to make a publication quality graphics. We need to be able to control where the ticks and labels are placed, modify the font size and possibly the labels used on the axes. In this section we will look at controling those properties in a matplotlib figure."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### Plot range"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The first thing we might want to configure is the ranges of the axes. We can do this using the `set_ylim` and `set_xlim` methods in the axis object, or `axis('tight')` for automatrically getting \"tightly fitted\" axes ranges:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 35,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAs0AAAEOCAYAAABy2yoGAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x109cb3750>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots(1, 3, figsize=(12, 4))\n",
    "\n",
    "axes[0].plot(x, x**2, x, x**3)\n",
    "axes[0].set_title(\"default axes ranges\")\n",
    "\n",
    "axes[1].plot(x, x**2, x, x**3)\n",
    "axes[1].axis('tight')\n",
    "axes[1].set_title(\"tight axes\")\n",
    "\n",
    "axes[2].plot(x, x**2, x, x**3)\n",
    "axes[2].set_ylim([0, 60])\n",
    "axes[2].set_xlim([2, 5])\n",
    "axes[2].set_title(\"custom axes range\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### Logarithmic scale"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "It is also possible to set a logarithmic scale for one or both axes. This functionality is in fact only one application of a more general transformation system in Matplotlib. Each of the axes' scales are set seperately using `set_xscale` and `set_yscale` methods which accept one parameter (with the value \"log\" in this case):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 36,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAlcAAAEOCAYAAACkUjImAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nkfIxqwAAAABJRU5ErkJggg==\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x108836e10>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots(1, 2, figsize=(10,4))\n",
    "      \n",
    "axes[0].plot(x, x**2, x, np.exp(x))\n",
    "axes[0].set_title(\"Normal scale\")\n",
    "\n",
    "axes[1].plot(x, x**2, x, np.exp(x))\n",
    "axes[1].set_yscale(\"log\")\n",
    "axes[1].set_title(\"Logarithmic scale (y)\");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### Scientific notation"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "With large numbers on axes, it is often better use scientific notation:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXgAAAEQCAYAAAC6Om+RAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nG9jKsfVNXL8AAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x1086350d0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(1, 1)\n",
    "      \n",
    "ax.plot(x, x**2, x, np.exp(x))\n",
    "ax.set_title(\"scientific notation\")\n",
    "\n",
    "ax.set_yticks([0, 50, 100, 150])\n",
    "\n",
    "from matplotlib import ticker\n",
    "formatter = ticker.ScalarFormatter(useMathText=True)\n",
    "formatter.set_scientific(True) \n",
    "formatter.set_powerlimits((-1,1)) \n",
    "ax.yaxis.set_major_formatter(formatter) "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Axis grid"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "With the `grid` method in the axis object, we can turn on and off grid lines. We can also customize the appearance of the grid lines using the same keyword arguments as the `plot` function:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 42,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAlYAAADMCAYAAACxx+0TAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x109d8d310>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots(1, 2, figsize=(10,3))\n",
    "\n",
    "# default grid appearance\n",
    "axes[0].plot(x, x**2, x, x**3, lw=2)\n",
    "axes[0].grid(True)\n",
    "\n",
    "# custom grid appearance\n",
    "axes[1].plot(x, x**2, x, x**3, lw=2)\n",
    "axes[1].grid(color='b', alpha=0.5, linestyle='dashed', linewidth=0.5)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Axes where x and y is zero"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 45,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXMAAADtCAYAAABNoZUVAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x10a47a110>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots()\n",
    "\n",
    "ax.spines['right'].set_color('none')\n",
    "ax.spines['top'].set_color('none')\n",
    "\n",
    "ax.xaxis.set_ticks_position('bottom')\n",
    "ax.spines['bottom'].set_position(('data',0)) # set position of x spine to x=0\n",
    "\n",
    "ax.yaxis.set_ticks_position('left')\n",
    "ax.spines['left'].set_position(('data',0))   # set position of y spine to y=0\n",
    "\n",
    "xx = np.linspace(-0.75, 1., 100)\n",
    "ax.plot(xx, xx**3);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Other 2D plot styles"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "In addition to the regular `plot` method, there are a number of other functions for generating different kind of plots. See the matplotlib plot gallery for a complete list of available plot types: http://matplotlib.org/gallery.html. Some of the more useful ones are show below:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 46,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "n = np.array([0,1,2,3,4,5])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 47,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAswAAADVCAYAAABDl6ZgAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nxAD+AX5xHVO2qhHDAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x10aa437d0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, axes = plt.subplots(1, 4, figsize=(12,3))\n",
    "\n",
    "axes[0].scatter(xx, xx + 0.25*np.random.randn(len(xx)))\n",
    "axes[0].set_title(\"scatter\")\n",
    "\n",
    "axes[1].step(n, n**2, lw=2)\n",
    "axes[1].set_title(\"step\")\n",
    "\n",
    "axes[2].bar(n, n**2, align=\"center\", width=0.5, alpha=0.5)\n",
    "axes[2].set_title(\"bar\")\n",
    "\n",
    "axes[3].fill_between(x, x**2, x**3, color=\"green\", alpha=0.5);\n",
    "axes[3].set_title(\"fill_between\");"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 49,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAtMAAAENCAYAAADNKOnzAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nmZmZWYccTJuZmZmZdej/A87LuhDi3OhLAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x10880b250>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# A histogram\n",
    "n = np.random.randn(100000)\n",
    "fig, axes = plt.subplots(1, 2, figsize=(12,4))\n",
    "\n",
    "axes[0].hist(n)\n",
    "axes[0].set_title(\"Default histogram\")\n",
    "axes[0].set_xlim((min(n), max(n)))\n",
    "\n",
    "axes[1].hist(n, cumulative=True, bins=50)\n",
    "axes[1].set_title(\"Cumulative detailed histogram\")\n",
    "axes[1].set_xlim((min(n), max(n)));"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Further reading"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "* http://www.matplotlib.org - The project web page for matplotlib.\n",
    "* https://github.com/matplotlib/matplotlib - The source code for matplotlib.\n",
    "* http://matplotlib.org/gallery.html - A large gallery showcaseing various types of plots matplotlib can create. Highly recommended! \n",
    "* http://www.loria.fr/~rougier/teaching/matplotlib - A good matplotlib tutorial.\n",
    "* http://scipy-lectures.github.io/matplotlib/matplotlib.html - Another good matplotlib reference.\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Versions"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "application/json": {
       "Software versions": [
        {
         "module": "Python",
         "version": "2.7.10 64bit [GCC 4.2.1 (Apple Inc. build 5577)]"
        },
        {
         "module": "IPython",
         "version": "3.2.1"
        },
        {
         "module": "OS",
         "version": "Darwin 14.1.0 x86_64 i386 64bit"
        },
        {
         "module": "numpy",
         "version": "1.9.2"
        },
        {
         "module": "scipy",
         "version": "0.16.0"
        },
        {
         "module": "matplotlib",
         "version": "1.4.3"
        }
       ]
      },
      "text/html": [
       "<table><tr><th>Software</th><th>Version</th></tr><tr><td>Python</td><td>2.7.10 64bit [GCC 4.2.1 (Apple Inc. build 5577)]</td></tr><tr><td>IPython</td><td>3.2.1</td></tr><tr><td>OS</td><td>Darwin 14.1.0 x86_64 i386 64bit</td></tr><tr><td>numpy</td><td>1.9.2</td></tr><tr><td>scipy</td><td>0.16.0</td></tr><tr><td>matplotlib</td><td>1.4.3</td></tr><tr><td colspan='2'>Sat Aug 15 11:30:23 2015 JST</td></tr></table>"
      ],
      "text/latex": [
       "\\begin{tabular}{|l|l|}\\hline\n",
       "{\\bf Software} & {\\bf Version} \\\\ \\hline\\hline\n",
       "Python & 2.7.10 64bit [GCC 4.2.1 (Apple Inc. build 5577)] \\\\ \\hline\n",
       "IPython & 3.2.1 \\\\ \\hline\n",
       "OS & Darwin 14.1.0 x86\\_64 i386 64bit \\\\ \\hline\n",
       "numpy & 1.9.2 \\\\ \\hline\n",
       "scipy & 0.16.0 \\\\ \\hline\n",
       "matplotlib & 1.4.3 \\\\ \\hline\n",
       "\\hline \\multicolumn{2}{|l|}{Sat Aug 15 11:30:23 2015 JST} \\\\ \\hline\n",
       "\\end{tabular}\n"
      ],
      "text/plain": [
       "Software versions\n",
       "Python 2.7.10 64bit [GCC 4.2.1 (Apple Inc. build 5577)]\n",
       "IPython 3.2.1\n",
       "OS Darwin 14.1.0 x86_64 i386 64bit\n",
       "numpy 1.9.2\n",
       "scipy 0.16.0\n",
       "matplotlib 1.4.3\n",
       "Sat Aug 15 11:30:23 2015 JST"
      ]
     },
     "execution_count": 1,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "%reload_ext version_information\n",
    "%version_information numpy, scipy, matplotlib"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 2",
   "language": "python",
   "name": "python2"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.6"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
